@@ -5,7 +5,7 @@ use warnings;
 use utf8;
 
 use vars qw($VERSION @ISA %EXPORT_TAGS @EXPORT @EXPORT_OK);
-$VERSION = '5.11';
+$VERSION = '5.12';
 
 =head1 NAME
 
@@ -45,6 +45,7 @@ require Exporter;
 use Regexp::Common  qw /profanity/;
 use Encode::ZapCP1252;
 
+use Labyrinth::Audit;
 use Labyrinth::Variables;
 
 # -------------------------------------
@@ -1043,19 +1044,194 @@ BEGIN
                 allowNetworking     => \&cleanup_attr_text,
         },
     );
+
     %safe_style = (
-        'color'             => \&cleanup_attr_color,
-        'border-color'      => \&cleanup_attr_color,
-        'background-color'  => \&cleanup_attr_color,
-        'padding'           => \&cleanup_attr_text,
-        'margin'            => \&cleanup_attr_text,
-        'border'            => \&cleanup_attr_text,
-        'visibility'        => \&cleanup_attr_text,
-        # XXX TODO: the CSS spec defines loads more, add 'em
+        'animation'                     => \&cleanup_attr_text,
+        'animation-name'                => \&cleanup_attr_text,
+        'animation-duration'            => \&cleanup_attr_text,
+        'animation-timing-function'     => \&cleanup_attr_text,
+        'animation-delay'               => \&cleanup_attr_text,
+        'animation-iteration-count'     => \&cleanup_attr_text,
+        'animation-direction'           => \&cleanup_attr_text,
+        'animation-play-state'          => \&cleanup_attr_text,
+        'appearance'                    => \&cleanup_attr_text,
+        'backface-visibility'           => \&cleanup_attr_text,
+        'background'                    => \&cleanup_attr_text,
+        'background-attachment'         => \&cleanup_attr_text,
+        'background-color'              => \&cleanup_attr_color,
+        'background-image'              => \&cleanup_attr_text,
+        'background-position'           => \&cleanup_attr_text,
+        'background-repeat'             => \&cleanup_attr_text,
+        'background-clip'               => \&cleanup_attr_text,
+        'background-origin'             => \&cleanup_attr_text,
+        'background-size'               => \&cleanup_attr_text,
+        'border'                        => \&cleanup_attr_text,
+        'border-bottom'                 => \&cleanup_attr_text,
+        'border-bottom-color'           => \&cleanup_attr_color,
+        'border-bottom-style'           => \&cleanup_attr_text,
+        'border-bottom-width'           => \&cleanup_attr_length,
+        'border-collapse'               => \&cleanup_attr_text,
+        'border-color'                  => \&cleanup_attr_color,
+        'border-left'                   => \&cleanup_attr_text,
+        'border-left-color'             => \&cleanup_attr_color,
+        'border-left-style'             => \&cleanup_attr_text,
+        'border-left-width'             => \&cleanup_attr_length,
+        'border-right'                  => \&cleanup_attr_text,
+        'border-right-color'            => \&cleanup_attr_color,
+        'border-right-style'            => \&cleanup_attr_text,
+        'border-right-width'            => \&cleanup_attr_length,
+        'border-spacing'                => \&cleanup_attr_text,
+        'border-style'                  => \&cleanup_attr_text,
+        'border-top'                    => \&cleanup_attr_text,
+        'border-top-color'              => \&cleanup_attr_color,
+        'border-top-style'              => \&cleanup_attr_text,
+        'border-top-width'              => \&cleanup_attr_length,
+        'border-width'                  => \&cleanup_attr_length,
+        'border-bottom-left-radius'     => \&cleanup_attr_text,
+        'border-bottom-right-radius'    => \&cleanup_attr_text,
+        'border-image'                  => \&cleanup_attr_text,
+        'border-image-outset'           => \&cleanup_attr_text,
+        'border-image-repeat'           => \&cleanup_attr_text,
+        'border-image-slice'            => \&cleanup_attr_text,
+        'border-image-source'           => \&cleanup_attr_text,
+        'border-image-width'            => \&cleanup_attr_length,
+        'border-radius'                 => \&cleanup_attr_text,
+        'border-top-left-radius'        => \&cleanup_attr_text,
+        'border-top-right-radius'       => \&cleanup_attr_text,
+        'bottom'                        => \&cleanup_attr_text,
+        'box'                           => \&cleanup_attr_text,
+        'box-align'                     => \&cleanup_attr_text,
+        'box-direction'                 => \&cleanup_attr_text,
+        'box-flex'                      => \&cleanup_attr_text,
+        'box-flex-group'                => \&cleanup_attr_text,
+        'box-lines'                     => \&cleanup_attr_text,
+        'box-ordinal-group'             => \&cleanup_attr_text,
+        'box-orient'                    => \&cleanup_attr_text,
+        'box-pack'                      => \&cleanup_attr_text,
+        'box-sizing'                    => \&cleanup_attr_text,
+        'box-shadow'                    => \&cleanup_attr_text,
+        'caption-side'                  => \&cleanup_attr_text,
+        'clear'                         => \&cleanup_attr_text,
+        'clip'                          => \&cleanup_attr_text,
+        'color'                         => \&cleanup_attr_color,
+        'column'                        => \&cleanup_attr_text,
+        'column-count'                  => \&cleanup_attr_text,
+        'column-fill'                   => \&cleanup_attr_text,
+        'column-gap'                    => \&cleanup_attr_text,
+        'column-rule'                   => \&cleanup_attr_text,
+        'column-rule-color'             => \&cleanup_attr_text,
+        'column-rule-style'             => \&cleanup_attr_text,
+        'column-rule-width'             => \&cleanup_attr_length,
+        'column-span'                   => \&cleanup_attr_text,
+        'column-width'                  => \&cleanup_attr_length,
+        'columns'                       => \&cleanup_attr_text,
+        'content'                       => \&cleanup_attr_text,
+        'counter-increment'             => \&cleanup_attr_text,
+        'counter-reset'                 => \&cleanup_attr_text,
+        'cursor'                        => \&cleanup_attr_text,
+        'direction'                     => \&cleanup_attr_text,
+        'display'                       => \&cleanup_attr_text,
+        'empty-cells'                   => \&cleanup_attr_text,
+        'float'                         => \&cleanup_attr_text,
+        'font'                          => \&cleanup_attr_text,
+        'font-family'                   => \&cleanup_attr_text,
+        'font-size'                     => \&cleanup_attr_text,
+        'font-style'                    => \&cleanup_attr_text,
+        'font-variant'                  => \&cleanup_attr_text,
+        'font-weight'                   => \&cleanup_attr_length,
+        '@font-face'                    => \&cleanup_attr_text,
+        'font-size-adjust'              => \&cleanup_attr_text,
+        'font-stretch'                  => \&cleanup_attr_text,
+        'grid-columns'                  => \&cleanup_attr_text,
+        'grid-rows'                     => \&cleanup_attr_text,
+        'hanging-punctuation'           => \&cleanup_attr_text,
+        'height'                        => \&cleanup_attr_length,
+        'icon'                          => \&cleanup_attr_text,
+        '@keyframes'                    => \&cleanup_attr_text,
+        'left'                          => \&cleanup_attr_length,
+        'letter-spacing'                => \&cleanup_attr_text,
+        'line-height'                   => \&cleanup_attr_text,
+        'list-style'                    => \&cleanup_attr_text,
+        'list-style-image'              => \&cleanup_attr_text,
+        'list-style-position'           => \&cleanup_attr_text,
+        'list-style-type'               => \&cleanup_attr_text,
+        'margin'                        => \&cleanup_attr_text,
+        'margin-bottom'                 => \&cleanup_attr_length,
+        'margin-left'                   => \&cleanup_attr_length,
+        'margin-right'                  => \&cleanup_attr_length,
+        'margin-top'                    => \&cleanup_attr_length,
+        'max-height'                    => \&cleanup_attr_length,
+        'max-width'                     => \&cleanup_attr_length,
+        'min-height'                    => \&cleanup_attr_length,
+        'min-width'                     => \&cleanup_attr_length,
+        'nav'                           => \&cleanup_attr_text,
+        'nav-down'                      => \&cleanup_attr_text,
+        'nav-index'                     => \&cleanup_attr_text,
+        'nav-left'                      => \&cleanup_attr_text,
+        'nav-right'                     => \&cleanup_attr_text,
+        'nav-up'                        => \&cleanup_attr_text,
+        'opacity'                       => \&cleanup_attr_text,
+        'outline'                       => \&cleanup_attr_text,
+        'outline-color'                 => \&cleanup_attr_color,
+        'outline-offset'                => \&cleanup_attr_text,
+        'outline-style'                 => \&cleanup_attr_text,
+        'outline-width'                 => \&cleanup_attr_length,
+        'overflow'                      => \&cleanup_attr_text,
+        'overflow-x'                    => \&cleanup_attr_text,
+        'overflow-y'                    => \&cleanup_attr_text,
+        'padding'                       => \&cleanup_attr_text,
+        'padding-bottom'                => \&cleanup_attr_length,
+        'padding-left'                  => \&cleanup_attr_length,
+        'padding-right'                 => \&cleanup_attr_length,
+        'padding-top'                   => \&cleanup_attr_length,
+        'page-break'                    => \&cleanup_attr_text,
+        'page-break-after'              => \&cleanup_attr_text,
+        'page-break-before'             => \&cleanup_attr_text,
+        'page-break-inside'             => \&cleanup_attr_text,
+        'perspective'                   => \&cleanup_attr_text,
+        'perspective-origin'            => \&cleanup_attr_text,
+        'position'                      => \&cleanup_attr_text,
+        'punctuation-trim'              => \&cleanup_attr_text,
+        'quotes'                        => \&cleanup_attr_text,
+        'resize'                        => \&cleanup_attr_text,
+        'right'                         => \&cleanup_attr_length,
+        'rotation'                      => \&cleanup_attr_text,
+        'rotation-point'                => \&cleanup_attr_text,
+        'table-layout'                  => \&cleanup_attr_text,
+        'target'                        => \&cleanup_attr_text,
+        'target-name'                   => \&cleanup_attr_text,
+        'target-new'                    => \&cleanup_attr_text,
+        'target-position'               => \&cleanup_attr_text,
+        'text'                          => \&cleanup_attr_text,
+        'text-align'                    => \&cleanup_attr_text,
+        'text-decoration'               => \&cleanup_attr_text,
+        'text-indent'                   => \&cleanup_attr_text,
+        'text-justify'                  => \&cleanup_attr_text,
+        'text-outline'                  => \&cleanup_attr_text,
+        'text-overflow'                 => \&cleanup_attr_text,
+        'text-shadow'                   => \&cleanup_attr_text,
+        'text-transform'                => \&cleanup_attr_text,
+        'text-wrap'                     => \&cleanup_attr_text,
+        'top'                           => \&cleanup_attr_length,
+        'transform'                     => \&cleanup_attr_text,
+        'transform-origin'              => \&cleanup_attr_text,
+        'transform-style'               => \&cleanup_attr_text,
+        'transition'                    => \&cleanup_attr_text,
+        'transition-property'           => \&cleanup_attr_text,
+        'transition-duration'           => \&cleanup_attr_text,
+        'transition-timing-function'    => \&cleanup_attr_text,
+        'transition-delay'              => \&cleanup_attr_text,
+        'vertical-align'                => \&cleanup_attr_text,
+        'visibility'                    => \&cleanup_attr_text,
+        'width'                         => \&cleanup_attr_length,
+        'white-space'                   => \&cleanup_attr_text,
+        'word-spacing'                  => \&cleanup_attr_text,
+        'word-break'                    => \&cleanup_attr_text,
+        'word-wrap'                     => \&cleanup_attr_text,
+        'z-index'                       => \&cleanup_attr_text
     );
 }
 
-        use Labyrinth::Audit;
 
 sub cleanup_attr_style {
     my @clean = ();
@@ -1092,7 +1268,7 @@ sub cleanup_attr_text {
     $_;
 }
 sub cleanup_attr_length {
-    /^(\d+\%?)$/ ? $1 : undef;
+    /^(\d+(\%|px|em)?)$/ ? $1 : undef;
 }
 sub cleanup_attr_color {
     /^(\w{2,20}|#[\da-fA-F]{6})$/ or die "color <<$_>> bad";
